@@ -18,9 +18,9 @@ def validate_content(node_type_path, args, api_address, headers):
     implementation = any('.yml' in x for x in node_file_list)
     definition = 'NodeType.tosca' in node_file_list
     if not implementation:
-        library_tools.write_to_log("Implementation missing for " + node_type_path + "\n")
+        print("Implementation missing for " + node_type_path + "\n")
     if not definition:
-        library_tools.write_to_log("Definition missing for " + node_type_path + "\n")
+        print("Definition missing for " + node_type_path + "\n")
 
     api_url = api_address + "/api/templates"
     name, group = get_name_type(node_type_path)
@@ -133,13 +133,17 @@ def list_versions(args, api_address, headers):
 
 
 def authorization(headers):
-    file = open(env_path + "/.token", "r")
-    env_token = file.read()
-    file.close()
-    if not env_token:
+    try:
+        file = open(env_path + "/.token", "r")
+        env_token = file.read()
+        file.close()
+        if not env_token:
+            print("Please log in.")
+        else:
+            headers["Authorization"] = "Bearer " + env_token
+    except Exception as e:
         print("Please log in.")
-    else:
-        headers["Authorization"] = "Bearer " + env_token
+        exit(1)
     return headers
 
 
@@ -215,7 +219,7 @@ def main():
             os.mkdir(env_path)
         except Exception as e:
             pass
-        api_endpoint = input("Enter API endpoint: ")
+        api_endpoint = input("Enter API endpoint (http://host:port):")
         file_endpoint = open(env_path + "/.endpoint", "w")
         file_endpoint.write(api_endpoint)
         file_endpoint.close()
@@ -270,7 +274,6 @@ def main():
     if args.command == "template":
         if args.template_options == "save":
             validate_content(args.path, args, api_address, headers)
-            print(library_tools.get_warnings_log())
         if args.template_options == "get":
             download_template(args, api_address, headers)
         if args.template_options == "list":
@@ -278,5 +281,3 @@ def main():
         if args.template_options == "version":
             if args.version_options == "list":
                 list_versions(args, api_address, headers)
-
-    print(library_tools.get_warnings_log())
